"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.programDataLayout = exports.deriveProgramDataAddress = exports.BPF_LOADER_UPGRADEABLE_PROGRAM_ID = void 0;
const web3_js_1 = require("@solana/web3.js");
const account_js_1 = require("./account.js");
exports.BPF_LOADER_UPGRADEABLE_PROGRAM_ID = new web3_js_1.PublicKey("BPFLoaderUpgradeab1e11111111111111111111111");
function deriveProgramDataAddress(programId) {
    return (0, account_js_1.deriveAddress)([new web3_js_1.PublicKey(programId).toBuffer()], exports.BPF_LOADER_UPGRADEABLE_PROGRAM_ID);
}
exports.deriveProgramDataAddress = deriveProgramDataAddress;
const pubKeyConversion = {
    to: (encoded) => new web3_js_1.PublicKey(encoded),
    from: (decoded) => decoded.toBytes(),
};
//neither anchor nor solana web3 have a built-in way to parse this
//see here: https://docs.rs/solana-program/latest/solana_program/bpf_loader_upgradeable/enum.UpgradeableLoaderState.html
exports.programDataLayout = [
    { name: "slot", binary: "uint", endianness: "little", size: 8 },
    {
        name: "upgradeAuthority",
        binary: "switch",
        idSize: 1,
        idTag: "isSome",
        layouts: [
            [[0, false], []],
            [
                [1, true],
                [
                    {
                        name: "value",
                        binary: "bytes",
                        size: 32,
                        custom: pubKeyConversion,
                    },
                ],
            ],
        ],
    },
];
//# sourceMappingURL=bpfLoaderUpgradeable.js.map